@@ -4,7 +4,7 @@
 #' @param P1 Vector containing the xy-coordinates of point 1
 #' @param P2 Vector containing the xy-coordinates of point 2
 #' @param r Radius for the circumference which is used to generate the arc. This parameter is necessary because there are infinite possible arcs that connect two points. In the case the radius is smaller than half the distance between \code{P1} and \code{P2}, there is no possible arc, so the function tells the user
-#' @param choice - Integer indicating which of the two possible centers is chosen to create the arcs. A value of 1 means the center of the circle that contains the arc is chosen in the direction of M + v, being M the middle point between P1 and P2 an v the orthogonal vector of P2 - P1 normalized to the appropriate length for creating the desired arc. A value of 2 means the center of the resulting circle is chosen in the direction of M - V. Remark: There are as well two options for vector v. If P1 = (a,b) and P2 = (c,d), v is written in the internal function as (b-d,c-a)
+#' @param choice - Integer indicating which of the two possible centers is chosen to create the arcs. A value of 1 means the center of the circle that contains the arc is chosen in the direction of M + v, being M the middle point between P1 and P2 and v the orthogonal vector of P2 - P1 normalized to the appropriate length for creating the desired arc. A value of 2 means the center of the resulting circle is chosen in the direction of M - V. Remark: There are as well two options for vector v. If P1 = (a,b) and P2 = (c,d), v is written in the internal function as (b-d,c-a)
 #' @param direction - String indicating the direction which is considered to create the arc, from the smaller to the higher angle. It has two possible values: "clock" (clockwise direction) and "anticlock" (anti-clockwise direction)
 #' @return Returns a vector which contains the center, radius and angles (0-360) that define the created arc
 #' @examples 
@@ -35,7 +35,7 @@
 #' @export
 CreateArcPointsDist<-function(P1, P2, r, choice, direction){
   if (r<DistancePoints(P1,P2)/2){
-    print("There is no possible arc for this radius. The radius needs to be greater")
+    print("There is no possible arc for this radius. The radius needs to be, at least, half the distance between P1 and P2")
     return()
   }
   x1=P2[1]
